src/lib/cache.h
changeset 8 400ddf1e7aa9
parent 7 997906f5fd2d
child 9 a31048ff76a2
--- a/src/lib/cache.h	Mon Dec 28 22:50:00 2009 +0200
+++ b/src/lib/cache.h	Mon Dec 28 23:15:18 2009 +0200
@@ -67,9 +67,11 @@
 int pt_cache_open (struct pt_cache **cache_ptr, const char *path, int mode);
 
 /**
  * Verify if the cached data has become stale compared to the given original file.
  */
-int pt_cache_stale (struct pt_cache *cache, const char *img_path);
+int pt_cache_status (struct pt_cache *cache, const char *img_path);
 
 /**
  * Update the cache data from the given PNG image.
@@ -67,9 +67,11 @@
 
 /**
- * Verify if the cached data has become stale compared to the given original file.
+ * Verify if the cached data eixsts, or has become stale compared to the given original file.
+ *
+ * @return one of pt_cache_status; <0 on error, 0 if fresh, >0 otherwise
  */